﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Data;
using Telerik.Windows.Controls;
using System.ComponentModel;

namespace SL.CurrentPosition
{
    public partial class MainPage : UserControl
    {
        public List<ColumnInfo> Visibles { get; set; }

        public MainPage()
        {
            InitializeComponent();
            this.Visibles = new List<ColumnInfo>();

            this.SampleGrid.ItemsSource = (from c in Enumerable.Range(0, 10) select new SampleData { ID = c, Name = "Name" + c }).ToList();
            this.SampleGrid.IsSynchronizedWithCurrentItem = false;
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {


        }

        public class ColumnInfo
        {
            public string Id { get; set; }
        }

        public class SampleData
        {
            public int ID { get; set; }
            public string Name { get; set; }
            public int Age { get; set; }
            public bool Active { get; set; }
        }

        private void ListBox_SelectionChanged(object sender, System.Windows.Controls.SelectionChangedEventArgs e)
        {
            UpdateVisibles(e);

            using (this.SampleGrid.DeferRefresh())
            {
                this.SampleGrid.SortDescriptors.Clear();
                
                this.SampleGrid.SortDescriptors.Add(new SortDescriptor()
                {
                    Member = "ID",
                    SortDirection = ListSortDirection.Ascending
                });
            }

                foreach (var column in this.SampleGrid.Columns)
                {
                    if (column.Header.ToString() != string.Empty && column.Header.ToString() != "ID")
                        column.IsVisible = false;
                }

                int index = 0;
                foreach (var item in this.Visibles)
                {
                    var temp = item; // work around closure issue.
                    var column = this.SampleGrid.Columns.FirstOrDefault<GridViewColumn>(c => c.UniqueName == temp.Id);
                    if (column == null)
                        throw new ArgumentException(string.Format("Unable to find a column with UniqueName {0}.",
                                                                  temp.Id));

                    column.DisplayIndex = index++;
                    column.IsVisible = true;


                }

        }

        private void UpdateVisibles(System.Windows.Controls.SelectionChangedEventArgs e)
        {
            if (e.AddedItems != null)
            {
                foreach (var item in e.AddedItems.OfType<GridViewColumn>())
                {
                    Visibles.Add(new ColumnInfo { Id = item.UniqueName });
                }
            }

            if (e.RemovedItems != null)
            {
                foreach (var item in e.RemovedItems.OfType<GridViewColumn>())
                {
                    var itemToRemove = Visibles.Where(c => c.Id == item.UniqueName).FirstOrDefault();

                    if (itemToRemove != null)
                    {
                        Visibles.Remove(itemToRemove);
                    }
                }
            }
        }
    }
}
